==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/EntailmentExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining_explanation/v1beta/entailment.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class EntailmentExplanationServiceGrpc {

  private EntailmentExplanationServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining_explanation.v1beta.EntailmentExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Entailments",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod;
    if ((getEntailmentsMethod = EntailmentExplanationServiceGrpc.getEntailmentsMethod) == null) {
      synchronized (EntailmentExplanationServiceGrpc.class) {
        if ((getEntailmentsMethod = EntailmentExplanationServiceGrpc.getEntailmentsMethod) == null) {
          EntailmentExplanationServiceGrpc.getEntailmentsMethod = getEntailmentsMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Entailments"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse.getDefaultInstance()))
              .setSchemaDescriptor(new EntailmentExplanationServiceMethodDescriptorSupplier("Entailments"))
              .build();
        }
      }
    }
    return getEntailmentsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static EntailmentExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static EntailmentExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static EntailmentExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceFutureStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class EntailmentExplanationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getEntailmentsMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getEntailmentsMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
                de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>(
                  this, METHODID_ENTAILMENTS)))
          .build();
    }
  }

  /**
   */
  public static final class EntailmentExplanationServiceStub extends io.grpc.stub.AbstractAsyncStub<EntailmentExplanationServiceStub> {
    private EntailmentExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class EntailmentExplanationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<EntailmentExplanationServiceBlockingStub> {
    private EntailmentExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class EntailmentExplanationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<EntailmentExplanationServiceFutureStub> {
    private EntailmentExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> entailments(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ENTAILMENTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final EntailmentExplanationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(EntailmentExplanationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ENTAILMENTS:
          serviceImpl.entailments((de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class EntailmentExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    EntailmentExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("EntailmentExplanationService");
    }
  }

  private static final class EntailmentExplanationServiceFileDescriptorSupplier
      extends EntailmentExplanationServiceBaseDescriptorSupplier {
    EntailmentExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class EntailmentExplanationServiceMethodDescriptorSupplier
      extends EntailmentExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    EntailmentExplanationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (EntailmentExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new EntailmentExplanationServiceFileDescriptorSupplier())
              .addMethod(getEntailmentsMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/mining_explanation/v1beta/EntailmentExplanationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining_explanation.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining_explanation/v1beta/entailment.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class EntailmentExplanationServiceGrpc {

  private EntailmentExplanationServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining_explanation.v1beta.EntailmentExplanationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Entailments",
      requestType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
      de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> getEntailmentsMethod;
    if ((getEntailmentsMethod = EntailmentExplanationServiceGrpc.getEntailmentsMethod) == null) {
      synchronized (EntailmentExplanationServiceGrpc.class) {
        if ((getEntailmentsMethod = EntailmentExplanationServiceGrpc.getEntailmentsMethod) == null) {
          EntailmentExplanationServiceGrpc.getEntailmentsMethod = getEntailmentsMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest, de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Entailments"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse.getDefaultInstance()))
              .setSchemaDescriptor(new EntailmentExplanationServiceMethodDescriptorSupplier("Entailments"))
              .build();
        }
      }
    }
    return getEntailmentsMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static EntailmentExplanationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static EntailmentExplanationServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingV2Stub>() {
        @java.lang.Override
        public EntailmentExplanationServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static EntailmentExplanationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceBlockingStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceBlockingStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static EntailmentExplanationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<EntailmentExplanationServiceFutureStub>() {
        @java.lang.Override
        public EntailmentExplanationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new EntailmentExplanationServiceFutureStub(channel, callOptions);
        }
      };
    return EntailmentExplanationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getEntailmentsMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service EntailmentExplanationService.
   */
  public static abstract class EntailmentExplanationServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return EntailmentExplanationServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service EntailmentExplanationService.
   */
  public static final class EntailmentExplanationServiceStub
      extends io.grpc.stub.AbstractAsyncStub<EntailmentExplanationServiceStub> {
    private EntailmentExplanationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceStub(channel, callOptions);
    }

    /**
     */
    public void entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service EntailmentExplanationService.
   */
  public static final class EntailmentExplanationServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<EntailmentExplanationServiceBlockingV2Stub> {
    private EntailmentExplanationServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service EntailmentExplanationService.
   */
  public static final class EntailmentExplanationServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<EntailmentExplanationServiceBlockingStub> {
    private EntailmentExplanationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse entailments(de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getEntailmentsMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service EntailmentExplanationService.
   */
  public static final class EntailmentExplanationServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<EntailmentExplanationServiceFutureStub> {
    private EntailmentExplanationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected EntailmentExplanationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new EntailmentExplanationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse> entailments(
        de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getEntailmentsMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ENTAILMENTS = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ENTAILMENTS:
          serviceImpl.entailments((de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getEntailmentsMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsRequest,
              de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentsResponse>(
                service, METHODID_ENTAILMENTS)))
        .build();
  }

  private static abstract class EntailmentExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    EntailmentExplanationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining_explanation.v1beta.EntailmentProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("EntailmentExplanationService");
    }
  }

  private static final class EntailmentExplanationServiceFileDescriptorSupplier
      extends EntailmentExplanationServiceBaseDescriptorSupplier {
    EntailmentExplanationServiceFileDescriptorSupplier() {}
  }

  private static final class EntailmentExplanationServiceMethodDescriptorSupplier
      extends EntailmentExplanationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    EntailmentExplanationServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (EntailmentExplanationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new EntailmentExplanationServiceFileDescriptorSupplier())
              .addMethod(getEntailmentsMethod())
              .build();
        }
      }
    }
    return result;
  }
}
